#ifndef CRID_PCI
#define CRID_PCI

/* BIOS32 signature: "_32_" */
#define BIOS32_SIGNATURE	(('_' << 0) + ('3' << 8) + ('2' << 16) + ('_' << 24))

/* PCI service signature: "$PCI" */
#define PCI_SERVICE		(('$' << 0) + ('P' << 8) + ('C' << 16) + ('I' << 24))
/* PCI signature: "PCI " */
#define PCI_SIGNATURE		(('P' << 0) + ('C' << 8) + ('I' << 16) + (' ' << 24))


#define PCIBIOS_PCI_BIOS_PRESENT 	0xb101
#define PCIBIOS_GET_ROUTING_OPTIONS	0xb10e

#define PCI_TO_PCI_BRIDGE_CLASS	0x00060400

/*
 * This is the standard structure used to identify the entry point
 * to the BIOS32 Service Directory, as documented in
 * 	Standard BIOS 32-bit Service Directory Proposal
 * 	Revision 0.4 May 24, 1993
 * 	Phoenix Technologies Ltd.
 *	Norwood, MA
 * and the PCI BIOS specification.
 */
union bios32 {
	struct {
		unsigned long signature;	/* _32_ */
		unsigned long entry;		/* 32 bit physical address */
		unsigned char revision;		/* Revision level, 0 */
		unsigned char length;		/* Length in paragraphs should be 01 */
		unsigned char checksum;		/* All bytes must add up to zero */
		unsigned char reserved[5]; 	/* Must be zero */
	} fields;
	char chars[16];
};
/*
 * Physical address of the service directory.  I don't know if we're
 * allowed to have more than one of these or not, so just in case
 * we'll make pcibios_present() take a memory start parameter and store
 * the array there.
 */

static struct {
	unsigned long address;
	unsigned short segment;
} __attribute__((packed)) bios32_indirect = { 0, __KERNEL_CS };

static struct {
	unsigned long address;
	unsigned short segment;
} __attribute__((packed))  pci_indirect = { 0, __KERNEL_CS };

struct irq_info {
        u8 bus, devfn;                  /* Bus, device and function */
        struct {
                u8 link;                /* IRQ line ID, chipset dependent, 0=not routed */
                u16 bitmap;             /* Available IRQs */
        } __attribute__((packed)) irq[4];
        u8 slot;                        /* Slot number, 0=onboard */
        u8 rfu;
} __attribute__((packed));

struct irq_routing_table {
        u32 signature;                  /* PIRQ_SIGNATURE should be here */
        u16 version;                    /* PIRQ_VERSION */
        u16 size;                       /* Table size in bytes */
        u8 rtr_bus, rtr_devfn;          /* Where the interrupt router lies */
        u16 exclusive_irqs;             /* IRQs devoted exclusively to PCI usage */
        u16 rtr_vendor, rtr_device;     /* Vendor and device ID of interrupt router */
        u32 miniport_data;              /* Crap */
        u8 rfu[11];
        u8 checksum;                    /* Modulo 256 checksum must give zero */
        struct irq_info slots[0];
} __attribute__((packed));

struct irq_routing_options {
	u16 size;
	struct irq_info *table;
	u16 segment;
} __attribute__((packed));


#endif
