#!/bin/bash
# This script performs various admin functions 
# after an Autoinstall.
# 
# On entry, the ram disk is mounted at /
# The SuSE NFS filesystem is available at /mnt/adm/mount
# the new filesystem is located at /mnt 
#
# After reboot, a log of this script can be found at
# /var/adm/inst-log/<script_name>.log 
#
#
# CGreen 9-26-02 - Added fstab entry for cdrom fix
# CGreen 10-2-02 - Fixed cdrom fstab entry for executing setup.sh

NFS_SERVER=~NFSSERVER~
CPQ_ROOT="/usr/cpqrdp/~SS~/sles7"

TARGET_MOUNT=/mnt

if [ ! -f "$TARGET_MOUNT/etc/passwd" ]; then
           echo "Running in installed system, aborting"
           exit
fi

#
# Try to set a default root password (encrypted) to compaq
# use htpasswd to create a different one.
#
epwd="IjGvb6BXeXDAs"

cp $TARGET_MOUNT/etc/shadow $TARGET_MOUNT/etc/shadow.old

$TARGET_MOUNT/usr/bin/awk -F: '
       		$1 == "root" && $2 == ""  { printf "%s:%s:%s:%s:%s:%s:%s:%s:%s\n",$1,epwd,$3,$4,$5,$6,$7,$8,$9 }
       		$1 == "root" && $2 != ""  { print $0 }     # never change root passwd, if it is already set
       		$1 != "root" { print $0 }' epwd=$epwd $TARGET_MOUNT/etc/shadow.old > $TARGET_MOUNT/etc/shadow


touch $TARGET_MOUNT/var/state/autoyast_run

#
# grab the Compaq value-add rpms
#

mkdir /mnt/nfs
mount $NFS_SERVER:$CPQ_ROOT /mnt/nfs

if [ $? -eq 0 ] ; then 

#
# Copy over add on packages to /tmp/cpq and install them via sles7.sh
# They will be configured manually by the user on reboot
#
	if [ -d /mnt/nfs/csp  ] ; then 
		mkdir -p $TARGET_MOUNT/tmp/cpq
		cp -r /mnt/nfs/csp/* $TARGET_MOUNT/tmp/cpq

		# install ProLiant value add RPMs at run level 3
                echo "#/bin/sh" > /mnt/etc/rc.d/rc3.d/S99plcsp
                echo "/tmp/cpq/csp.sh" >> /mnt/etc/rc.d/rc3.d/S99plcsp
                echo "exit 0" >> /mnt/etc/rc.d/rc3.d/S99plcsp
                chmod +x /mnt/etc/rc.d/rc3.d/S99plcsp

		# csp.sh installs the csp and cleans up the startup script 
                echo "#/bin/sh" > /mnt/tmp/cpq/csp.sh
                echo "cd /tmp/cpq" >> /mnt/tmp/cpq/csp.sh
                echo "./sles7.sh" >> /mnt/tmp/cpq/csp.sh
		echo "rm /etc/rc.d/rc3.d/S99plcsp" >> /mnt/tmp/cpq/csp.sh
		echo "rm /etc/rc.d/rc2.d/S99reboot" >> /mnt/tmp/cpq/csp.sh
                echo "sync" >> /mnt/tmp/cpq/csp.sh
		echo "reboot" >> /mnt/tmp/cpq/csp.sh
		chmod +x /mnt/tmp/cpq/csp.sh

		# if Auto Yast goes to runlevel 2, that means lilo configuration failed,
		# (Always happens on bl10e, therefore we edit lilo.conf in bl10e.info
		# and run lilo here)
		echo "#/bin/sh" > /mnt/etc/rc.d/rc2.d/S99reboot 
		echo "cd /tmp/cpq" >> /mnt/etc/rc.d/rc2.d/S99reboot
		echo "/sbin/lilo" >> /mnt/etc/rc.d/rc2.d/S99reboot 
		echo "echo;echo;echo S99reboot: Rebooting in 3 minutes... " >> /mnt/etc/rc.d/rc2.d/S99reboot
		echo "sync" >> /mnt/etc/rc.d/rc2.d/S99reboot
		echo "/sbin/shutdown -r +3" >> /mnt/etc/rc.d/rc2.d/S99reboot 
		chmod +x /mnt/etc/rc.d/rc2.d/S99reboot 

		sync
	fi
fi 
	
#
# Add any additional postinstall steps below.
#


# end 

# CGreen 9-26-02 - Add cdrom device entry for proper cd mounting
# CGreen 10-2-02 - Fixed entry to read "owner" instead of "user" for proper execution of setup.sh
if grep -q "/dev/hda" /mnt/etc/fstab 
then
    echo "/dev/hdc     /media/cdrom      iso9660      ro,noauto,owner 0 0" >> /mnt/etc/fstab 
else
    if grep -q "/dev/hde" /mnt/etc/fstab
    then
        echo "/dev/hdc     /media/cdrom      iso9660      ro,noauto,owner 0 0" >> /mnt/etc/fstab 
    else
        echo "/dev/hda     /media/cdrom      iso9660      ro,noauto,owner 0 0" >> /mnt/etc/fstab 
    fi
fi

exit 0 

